@@ -43,20 +43,30 @@
 #'   Extra arguments to [print.tbl()] or [format.tbl()].
 #' @param n
 #'   Actual number of rows to print.
-#'   No [option]s should be considered by implementations of this method.
+#'   No [options][pillar_options] should be considered
+#'   by implementations of this method.
 #' @param max_extra_cols
 #'   Number of columns to print abbreviated information for,
 #'   if the width is too small for the entire tibble.
-#'   No [option]s should be considered by implementations of this method.
+#'   No [options][pillar_options] should be considered
+#'   by implementations of this method.
+#' @param max_footer_lines
+#'   Maximum number of lines for the footer.
+#'   No [options][pillar_options] should be considered
+#'   by implementations of this method.
+#' @param focus `r lifecycle::badge("experimental")`
 #'
+#'   Names of columns to show preferentially if space is tight.
 #' @return
 #'   An object that can be passed as `setup` argument to
 #'   [tbl_format_header()], [tbl_format_body()], and [tbl_format_footer()].
 #' @export
-#' @examplesIf requireNamespace("palmerpenguins", quietly = TRUE)
+#' @examplesIf rlang::is_installed("palmerpenguins")
 #' tbl_format_setup(palmerpenguins::penguins)
 tbl_format_setup <- function(x, width = NULL, ...,
-                             n = NULL, max_extra_cols = NULL) {
+                             n = NULL, max_extra_cols = NULL,
+                             max_footer_lines = NULL,
+                             focus = NULL) {
   "!!!!DEBUG tbl_format_setup()"
 
   width <- get_width_print(width)
@@ -64,15 +74,20 @@ tbl_format_setup <- function(x, width = NULL, ...,
   n <- get_n_print(n, nrow(x))
 
   max_extra_cols <- get_max_extra_cols(max_extra_cols)
+  max_footer_lines <- get_max_footer_lines(max_footer_lines)
 
   # Calls UseMethod("tbl_format_setup"),
   # allows using default values in S3 dispatch
-  out <- tbl_format_setup_(x, width, ..., n = n, max_extra_cols = max_extra_cols)
+  out <- tbl_format_setup_(
+    x, width, ...,
+    n = n, max_extra_cols = max_extra_cols, max_footer_lines = max_footer_lines,
+    focus = focus
+  )
   return(out)
   UseMethod("tbl_format_setup")
 }
 
-tbl_format_setup_ <- function(x, width, ..., n, max_extra_cols) {
+tbl_format_setup_ <- function(x, width, ..., n, max_extra_cols, max_footer_lines, focus = NULL) {
   UseMethod("tbl_format_setup")
 }
 
@@ -84,7 +99,7 @@ tbl_format_setup_ <- function(x, width, ..., n, max_extra_cols) {
 #' @rdname tbl_format_setup
 #' @export
 tbl_format_setup.tbl <- function(x, width, ...,
-                                 n, max_extra_cols) {
+                                 n, max_extra_cols, max_footer_lines, focus) {
   "!!!!DEBUG tbl_format_setup.tbl()"
 
   # Number of rows
@@ -125,7 +140,8 @@ tbl_format_setup.tbl <- function(x, width, ...,
     df,
     has_row_id = if (.row_names_info(x) > 0) "*" else TRUE,
     width = width,
-    controller = x
+    controller = x,
+    focus = focus
   )
 
   body <- colonnade$body
@@ -148,7 +164,8 @@ tbl_format_setup.tbl <- function(x, width, ...,
     rows_missing = rows_missing,
     rows_total = rows,
     extra_cols = extra_cols,
-    extra_cols_total = extra_cols_total
+    extra_cols_total = extra_cols_total,
+    max_footer_lines = max_footer_lines
   )
 }
 
@@ -177,11 +194,13 @@ tbl_format_setup.tbl <- function(x, width, ...,
 #'   as a character vector of formatted column names and types.
 #' @param extra_cols_total The total number of columns, may be larger than
 #'   `length(extra_cols)`.
+#' @param max_footer_lines The maximum number of lines in the footer.
 #'
 #' @keywords internal
 new_tbl_format_setup <- function(x, df, width, tbl_sum, body,
                                  rows_missing, rows_total,
-                                 extra_cols, extra_cols_total) {
+                                 extra_cols, extra_cols_total,
+                                 max_footer_lines) {
   trunc_info <- list(
     x = x,
     df = df,
@@ -191,7 +210,8 @@ new_tbl_format_setup <- function(x, df, width, tbl_sum, body,
     rows_missing = rows_missing,
     rows_total = rows_total,
     extra_cols = extra_cols,
-    extra_cols_total = extra_cols_total
+    extra_cols_total = extra_cols_total,
+    max_footer_lines = max_footer_lines
   )
 
   structure(trunc_info, class = "pillar_tbl_format_setup")
