@@ -39,7 +39,7 @@ setup
 
 ## ----show_source = TRUE-------------------------------------------------------
 #  tbl_format_setup <- function (x, width = NULL, ..., n = NULL, max_extra_cols = NULL, 
-#      max_footer_lines = NULL) 
+#      max_footer_lines = NULL, focus = NULL) 
 #  {
 #      "!!!!DEBUG tbl_format_setup()"
 #      width <- get_width_print(width)
@@ -47,13 +47,14 @@ setup
 #      max_extra_cols <- get_max_extra_cols(max_extra_cols)
 #      max_footer_lines <- get_max_footer_lines(max_footer_lines)
 #      out <- tbl_format_setup_(x, width, ..., n = n, max_extra_cols = max_extra_cols, 
-#          max_footer_lines = max_footer_lines)
+#          max_footer_lines = max_footer_lines, focus = focus)
 #      return(out)
 #      UseMethod("tbl_format_setup")
 #  }
 
 ## ----show_source = TRUE-------------------------------------------------------
-#  tbl_format_setup.tbl <- function (x, width, ..., n, max_extra_cols, max_footer_lines) 
+#  tbl_format_setup.tbl <- function (x, width, ..., n, max_extra_cols, max_footer_lines, 
+#      focus) 
 #  {
 #      "!!!!DEBUG tbl_format_setup.tbl()"
 #      rows <- nrow(x)
@@ -86,7 +87,7 @@ setup
 #      colonnade <- ctl_colonnade(df, has_row_id = if (.row_names_info(x) > 
 #          0) 
 #          "*"
-#      else TRUE, width = width, controller = x)
+#      else TRUE, width = width, controller = x, focus = focus)
 #      body <- colonnade$body
 #      extra_cols <- colonnade$extra_cols
 #      extra_cols_total <- length(extra_cols)
@@ -138,29 +139,35 @@ typeof(tbl_format_body(tbl, setup))
 #  }
 
 ## -----------------------------------------------------------------------------
-ctl_new_compound_pillar(tbl, tbl$a, width = 20)
-ctl_new_compound_pillar(tbl, tbl$b, width = 20)
+ctl_new_pillar_list(tbl, tbl$a, width = 20)
+ctl_new_pillar_list(tbl, tbl$b, width = 20)
 
 ## ----show_source = TRUE-------------------------------------------------------
-#  ctl_new_compound_pillar.tbl <- function (controller, x, width, ..., title = NULL) 
+#  ctl_new_pillar_list.tbl <- function (controller, x, width, ..., title = NULL, first_pillar = NULL) 
 #  {
-#      "!!!!DEBUG ctl_new_compound_pillar.tbl(`v(width)`, `v(title)`)"
+#      "!!!!DEBUG ctl_new_pillar_list.tbl(`v(width)`, `v(title)`)"
 #      if (is.data.frame(x)) {
-#          new_data_frame_pillar(x, controller, width, title = title)
+#          new_data_frame_pillar_list(x, controller, width, title = title, 
+#              first_pillar = first_pillar)
 #      }
 #      else if (is.matrix(x)) {
-#          new_matrix_pillar(x, controller, width, title = title)
+#          new_matrix_pillar_list(x, controller, width, title = title, 
+#              first_pillar = first_pillar)
 #      }
 #      else if (is.array(x) && length(dim(x)) > 1) {
-#          new_array_pillar(x, controller, width, title = title)
+#          new_array_pillar_list(x, controller, width, title = title, 
+#              first_pillar = first_pillar)
+#      }
+#      else if (is.null(first_pillar)) {
+#          list(ctl_new_pillar(controller, x, width, ..., title = prepare_title(title)))
 #      }
 #      else {
-#          ctl_new_pillar(controller, x, width, ..., title = prepare_title(title))
+#          list(first_pillar)
 #      }
 #  }
 
 ## -----------------------------------------------------------------------------
-ctl_new_compound_pillar(tbl, tbl$a, width = 20)
+ctl_new_pillar(tbl, tbl$a, width = 20)
 
 ## ----show_source = TRUE-------------------------------------------------------
 #  ctl_new_pillar.tbl <- function (controller, x, width, ..., title = NULL) 
@@ -179,14 +186,15 @@ ctl_new_compound_pillar(tbl, tbl$a, width = 20)
 #  }
 
 ## ----show_source = TRUE-------------------------------------------------------
-#  new_pillar <- function (components, ..., width = NULL, class = NULL) 
+#  new_pillar <- function (components, ..., width = NULL, class = NULL, extra = NULL) 
 #  {
 #      "!!!!DEBUG new_pillar(`v(width)`, `v(class)`)"
 #      check_dots_empty()
 #      if (length(components) > 0 && !is_named(components)) {
 #          abort("All components must have names.")
 #      }
-#      structure(components, width = width, class = c(class, "pillar"))
+#      structure(components, width = width, class = c(class, "pillar"), 
+#          extra = extra)
 #  }
 
 ## ----show_source = TRUE-------------------------------------------------------
@@ -197,8 +205,8 @@ ctl_new_compound_pillar(tbl, tbl$a, width = 20)
 #      }
 #      if (is.null(width)) {
 #          widths <- pillar_get_widths(x)
-#          width <- sum(widths) - length(widths) + 1
+#          width <- sum(widths) + length(widths) - 1
 #      }
-#      new_vertical(pillar_format_parts_2(x, width)$aligned[[1]])
+#      as_glue(pillar_format_parts_2(x, width)$aligned)
 #  }
 
