@@ -1,4 +1,5 @@
-test_that("space distribution never removes space, and distributes space from left to right based on need", {
+test_that("space distribution never removes space", {
+  # and distributes space from left to right based on need
   expect_equal(
     colonnade_distribute_space(c(5, 6, 6), c(11, 8, 8), 18),
     c(0, 0, 0)
